=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2012-03-14 11:49:29 +0000
+++ bzrlib/branch.py	2012-03-14 13:34:43 +0000
@@ -767,19 +767,6 @@
         raise NotImplementedError(self.print_file)
 
     @needs_write_lock
-    def _set_revision_history(self, rev_history):
-        if len(rev_history) == 0:
-            revid = _mod_revision.NULL_REVISION
-        else:
-            revid = rev_history[-1]
-        if rev_history != self._lefthand_history(revid):
-            raise errors.NotLefthandHistory(rev_history)
-        self.set_last_revision_info(len(rev_history), revid)
-        self._cache_revision_history(rev_history)
-        for hook in Branch.hooks['set_rh']:
-            hook(self, rev_history)
-
-    @needs_write_lock
     def set_last_revision_info(self, revno, revision_id):
         """Set the last revision of this branch.
 
@@ -1790,8 +1777,8 @@
 class BranchHooks(Hooks):
     """A dictionary mapping hook name to a list of callables for branch hooks.
 
-    e.g. ['set_rh'] Is the list of items to be called when the
-    set_revision_history function is invoked.
+    e.g. ['post_push'] Is the list of items to be called when the
+    push function is invoked.
     """
 
     def __init__(self):
@@ -1801,12 +1788,6 @@
         notified.
         """
         Hooks.__init__(self, "bzrlib.branch", "Branch.hooks")
-        self.add_hook('set_rh',
-            "Invoked whenever the revision history has been set via "
-            "set_revision_history. The api signature is (branch, "
-            "revision_history), and the branch will be write-locked. "
-            "The set_rh hook can be expensive for bzr to trigger, a better "
-            "hook to use is Branch.post_change_branch_tip.", (0, 15))
         self.add_hook('open',
             "Called with the Branch object that has been opened after a "
             "branch is opened.", (1, 8))
@@ -2781,8 +2762,6 @@
         self._write_revision_history(rev_history)
         self._clear_cached_state()
         self._cache_revision_history(rev_history)
-        for hook in Branch.hooks['set_rh']:
-            hook(self, rev_history)
         if Branch.hooks['post_change_branch_tip']:
             self._run_post_change_branch_tip_hooks(old_revno, old_revid)
 

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2012-03-14 11:49:29 +0000
+++ bzrlib/remote.py	2012-03-14 13:34:43 +0000
@@ -3792,20 +3792,6 @@
             raise errors.UnexpectedSmartServerResponse(response)
         self._run_post_change_branch_tip_hooks(old_revno, old_revid)
 
-    @needs_write_lock
-    def _set_revision_history(self, rev_history):
-        # Send just the tip revision of the history; the server will generate
-        # the full history from that.  If the revision doesn't exist in this
-        # branch, NoSuchRevision will be raised.
-        if rev_history == []:
-            rev_id = 'null:'
-        else:
-            rev_id = rev_history[-1]
-        self._set_last_revision(rev_id)
-        for hook in branch.Branch.hooks['set_rh']:
-            hook(self, rev_history)
-        self._cache_revision_history(rev_history)
-
     def _get_parent_location(self):
         medium = self._client._medium
         if medium._is_remote_before((1, 13)):

=== modified file 'bzrlib/smart/branch.py'
--- bzrlib/smart/branch.py	2011-12-19 13:23:58 +0000
+++ bzrlib/smart/branch.py	2012-03-14 13:34:43 +0000
@@ -299,13 +299,12 @@
 
     def do_tip_change_with_locked_branch(self, branch, new_last_revision_id):
         if new_last_revision_id == 'null:':
-            branch._set_revision_history([])
+            branch.set_last_revision_info(0, new_last_revision_id)
         else:
             if not branch.repository.has_revision(new_last_revision_id):
                 return FailedSmartServerResponse(
                     ('NoSuchRevision', new_last_revision_id))
-            branch._set_revision_history(branch._lefthand_history(
-                new_last_revision_id, None, None))
+            branch.generate_revision_history(new_last_revision_id, None, None)
         return SuccessfulSmartServerResponse(('ok',))
 
 

=== modified file 'bzrlib/tests/per_branch/test_check.py'
--- bzrlib/tests/per_branch/test_check.py	2011-04-19 14:17:24 +0000
+++ bzrlib/tests/per_branch/test_check.py	2012-03-14 13:34:43 +0000
@@ -44,18 +44,9 @@
 
         r5 = tree.commit('five')
         # Now, try to set an invalid history
-        try:
-            self.applyDeprecated(deprecated_in((2, 4, 0)),
-                tree.branch.set_revision_history, [r1, r2b, r5])
-            if tree.branch.last_revision_info() != (3, r5):
-                # RemoteBranch silently corrects an impossible revision
-                # history given to set_revision_history.  It can be tricked
-                # with set_last_revision_info though.
-                tree.branch.set_last_revision_info(3, r5)
-        except errors.NotLefthandHistory:
-            # Branch5 allows set_revision_history to be wrong
-            # Branch6 raises NotLefthandHistory, but we can force bogus stuff
-            # with set_last_revision_info
+        if getattr(tree.branch, "_set_revision_history", None) is not None:
+            tree.branch._set_revision_history([r1, r2b, r5])
+        else:
             tree.branch.set_last_revision_info(3, r5)
 
         tree.lock_read()

=== modified file 'bzrlib/tests/per_branch/test_hooks.py'
--- bzrlib/tests/per_branch/test_hooks.py	2011-05-08 13:46:49 +0000
+++ bzrlib/tests/per_branch/test_hooks.py	2012-03-14 13:34:43 +0000
@@ -70,76 +70,6 @@
             self.assertEqual([expected_params], hook_calls)
 
 
-class TestSetRevisionHistoryHook(ChangeBranchTipTestCase):
-
-    def setUp(self):
-        self.hook_calls = []
-        super(TestSetRevisionHistoryHook, self).setUp()
-
-    def capture_set_rh_hook(self, branch, rev_history):
-        """Capture post set-rh hook calls to self.hook_calls.
-
-        The call is logged, as is some state of the branch.
-        """
-        self.hook_calls.append(
-            ('set_rh', branch, rev_history, branch.is_locked()))
-
-    def test_set_rh_empty_history(self):
-        branch = self.make_branch('source')
-        _mod_branch.Branch.hooks.install_named_hook(
-            'set_rh', self.capture_set_rh_hook, None)
-        self.applyDeprecated(deprecated_in((2, 4, 0)),
-            branch.set_revision_history, [])
-        expected_params = ('set_rh', branch, [], True)
-        self.assertHookCalls(expected_params, branch)
-
-    def test_set_rh_nonempty_history(self):
-        tree = self.make_branch_and_memory_tree('source')
-        tree.lock_write()
-        tree.add('')
-        tree.commit('another commit', rev_id='f\xc2\xb5')
-        tree.commit('empty commit', rev_id='foo')
-        tree.unlock()
-        branch = tree.branch
-        _mod_branch.Branch.hooks.install_named_hook(
-            'set_rh', self.capture_set_rh_hook, None)
-        # some branches require that their history be set to a revision in the
-        # repository
-        self.applyDeprecated(deprecated_in((2, 4, 0)),
-            branch.set_revision_history, ['f\xc2\xb5'])
-        expected_params =('set_rh', branch, ['f\xc2\xb5'], True)
-        self.assertHookCalls(expected_params, branch)
-
-    def test_set_rh_branch_is_locked(self):
-        branch = self.make_branch('source')
-        _mod_branch.Branch.hooks.install_named_hook(
-            'set_rh', self.capture_set_rh_hook, None)
-        self.applyDeprecated(deprecated_in((2, 4, 0)),
-            branch.set_revision_history, [])
-        expected_params = ('set_rh', branch, [], True)
-        self.assertHookCalls(expected_params, branch)
-
-    def test_set_rh_calls_all_hooks_no_errors(self):
-        branch = self.make_branch('source')
-        _mod_branch.Branch.hooks.install_named_hook(
-            'set_rh', self.capture_set_rh_hook, None)
-        _mod_branch.Branch.hooks.install_named_hook(
-            'set_rh', self.capture_set_rh_hook, None)
-        self.applyDeprecated(deprecated_in((2, 4, 0)),
-            branch.set_revision_history, [])
-        expected_calls = [('set_rh', branch, [], True),
-            ('set_rh', branch, [], True),
-            ]
-        if isinstance(branch, remote.RemoteBranch):
-            # For a remote branch, both the server and the client will raise
-            # set_rh, and the server will do so first because that is where
-            # the change takes place.
-            self.assertEqual(expected_calls, self.hook_calls[2:])
-            self.assertEqual(4, len(self.hook_calls))
-        else:
-            self.assertEqual(expected_calls, self.hook_calls)
-
-
 class TestOpen(tests.TestCaseWithMemoryTransport):
 
     def capture_hook(self, branch):
@@ -389,12 +319,6 @@
         self.assertEqual(length, len(self.pre_hook_calls))
         self.assertEqual(length, len(self.post_hook_calls))
 
-    def test_set_revision_history(self):
-        branch = self.make_branch('')
-        self.applyDeprecated(deprecated_in((2, 4, 0)),
-            branch.set_revision_history, [])
-        self.assertPreAndPostHooksWereInvoked(branch, True)
-
     def test_set_last_revision_info(self):
         branch = self.make_branch('')
         branch.set_last_revision_info(0, revision.NULL_REVISION)

=== modified file 'bzrlib/tests/per_workingtree/test_workingtree.py'
--- bzrlib/tests/per_workingtree/test_workingtree.py	2012-02-23 23:26:35 +0000
+++ bzrlib/tests/per_workingtree/test_workingtree.py	2012-03-14 13:34:43 +0000
@@ -343,19 +343,16 @@
         wt.set_last_revision('null:')
         wt.commit('A', allow_pointless=True, rev_id='A')
         self.assertEqual(['A'], wt.get_parent_ids())
-        # None is aways in the branch
+        # null: is aways in the branch
         wt.set_last_revision('null:')
         self.assertEqual([], wt.get_parent_ids())
         # and now we can set it to 'A'
         # because some formats mutate the branch to set it on the tree
         # we need to alter the branch to let this pass.
-        try:
-            self.applyDeprecated(symbol_versioning.deprecated_in((2, 4, 0)),
-                wt.branch.set_revision_history, ['A', 'B'])
-        except errors.NoSuchRevision, e:
-            self.assertEqual('B', e.revision)
+        if getattr(wt.branch, "_set_revision_history", None) is None:
             raise TestSkipped("Branch format does not permit arbitrary"
                               " history")
+        wt.branch._set_revision_history(['A', 'B'])
         wt.set_last_revision('A')
         self.assertEqual(['A'], wt.get_parent_ids())
         self.assertRaises(errors.ReservedId, wt.set_last_revision, 'A:')

=== modified file 'bzrlib/tests/test_branch.py'
--- bzrlib/tests/test_branch.py	2012-03-08 16:23:53 +0000
+++ bzrlib/tests/test_branch.py	2012-03-14 13:34:43 +0000
@@ -363,23 +363,6 @@
         self.assertPathDoesNotExist('a/.bzr/branch/bound')
         self.assertEqual('ftp://example.com', branch.get_bound_location())
 
-    def test_set_revision_history(self):
-        builder = self.make_branch_builder('.', format=self.get_format_name())
-        builder.build_snapshot('foo', None,
-            [('add', ('', None, 'directory', None))],
-            message='foo')
-        builder.build_snapshot('bar', None, [], message='bar')
-        branch = builder.get_branch()
-        branch.lock_write()
-        self.addCleanup(branch.unlock)
-        self.applyDeprecated(symbol_versioning.deprecated_in((2, 4, 0)),
-            branch.set_revision_history, ['foo', 'bar'])
-        self.applyDeprecated(symbol_versioning.deprecated_in((2, 4, 0)),
-                branch.set_revision_history, ['foo'])
-        self.assertRaises(errors.NotLefthandHistory,
-            self.applyDeprecated, symbol_versioning.deprecated_in((2, 4, 0)),
-            branch.set_revision_history, ['bar'])
-
     def do_checkout_test(self, lightweight=False):
         tree = self.make_branch_and_tree('source',
             format=self.get_format_name_subtree())

